@@ -17,4 +17,4 @@ class Currency(Object):
         return self._format(self.convert_float(value))
 
     def convert_float(self, value):
-        return self.round(self.usdvalue * value, 2)
+        return self.round(float(self.usdvalue) * float(value), 2)
